@@ -22,7 +22,6 @@ import sys
 from typing import TYPE_CHECKING, Any, Dict, Set, Union
 
 from ansiblelint.rules import AnsibleLintRule
-from ansiblelint.testing import RunFromText
 
 if TYPE_CHECKING:
     from typing import Optional
@@ -32,41 +31,41 @@ if TYPE_CHECKING:
 
 # Despite documentation mentioning 'preserve' only these modules support it:
 _modules_with_preserve = (
-    'copy',
-    'template',
+    "copy",
+    "template",
 )
 
 _MODULES: Set[str] = {
-    'archive',
-    'community.general.archive',
-    'assemble',
-    'ansible.builtin.assemble',
-    'copy',  # supports preserve
-    'ansible.builtin.copy',
-    'file',
-    'ansible.builtin.file',
-    'replace',  # implicit preserve behavior but mode: preserve is invalid
-    'ansible.builtin.replace',
-    'template',  # supports preserve
-    'ansible.builtin.template',
+    "archive",
+    "community.general.archive",
+    "assemble",
+    "ansible.builtin.assemble",
+    "copy",  # supports preserve
+    "ansible.builtin.copy",
+    "file",
+    "ansible.builtin.file",
+    "replace",  # implicit preserve behavior but mode: preserve is invalid
+    "ansible.builtin.replace",
+    "template",  # supports preserve
+    "ansible.builtin.template",
     # 'unarchive',  # disabled because .tar.gz files can have permissions inside
 }
 
 _MODULES_WITH_CREATE: Dict[str, bool] = {
-    'blockinfile': False,
-    'ansible.builtin.blockinfile': False,
-    'htpasswd': True,
-    'community.general.htpasswd': True,
-    'ini_file': True,
-    'community.general.ini_file': True,
-    'lineinfile': False,
-    'ansible.builtin.lineinfile': False,
+    "blockinfile": False,
+    "ansible.builtin.blockinfile": False,
+    "htpasswd": True,
+    "community.general.htpasswd": True,
+    "ini_file": True,
+    "community.general.ini_file": True,
+    "lineinfile": False,
+    "ansible.builtin.lineinfile": False,
 }
 
 
 class MissingFilePermissionsRule(AnsibleLintRule):
     id = "risky-file-permissions"
-    shortdesc = 'File permissions unset or incorrect'
+    shortdesc = "File permissions unset or incorrect"
     description = (
         "Missing or unsupported mode parameter can cause unexpected file "
         "permissions based "
@@ -75,23 +74,23 @@ class MissingFilePermissionsRule(AnsibleLintRule):
         f"only by {', '.join(_modules_with_preserve)} modules. "
         "See https://github.com/ansible/ansible/issues/71200"
     )
-    severity = 'VERY_HIGH'
-    tags = ['unpredictability', 'experimental']
-    version_added = 'v4.3.0'
+    severity = "VERY_HIGH"
+    tags = ["unpredictability", "experimental"]
+    version_added = "v4.3.0"
 
     _modules = _MODULES
     _modules_with_create = _MODULES_WITH_CREATE
 
     def matchtask(
-        self, task: Dict[str, Any], file: 'Optional[Lintable]' = None
+        self, task: Dict[str, Any], file: "Optional[Lintable]" = None
     ) -> Union[bool, str]:
         module = task["action"]["__ansible_module__"]
-        mode = task['action'].get('mode', None)
+        mode = task["action"].get("mode", None)
 
         if module not in self._modules and module not in self._modules_with_create:
             return False
 
-        if mode == 'preserve' and module not in _modules_with_preserve:
+        if mode == "preserve" and module not in _modules_with_preserve:
             return True
 
         if module in self._modules_with_create:
@@ -99,25 +98,25 @@ class MissingFilePermissionsRule(AnsibleLintRule):
             return create and mode is None
 
         # A file that doesn't exist cannot have a mode
-        if task['action'].get('state', None) == "absent":
+        if task["action"].get("state", None) == "absent":
             return False
 
         # A symlink always has mode 0777
-        if task['action'].get('state', None) == "link":
+        if task["action"].get("state", None) == "link":
             return False
 
         # Recurse on a directory does not allow for an uniform mode
-        if task['action'].get('recurse', None):
+        if task["action"].get("recurse", None):
             return False
 
         # The file module does not create anything when state==file (default)
-        if module == "file" and task['action'].get('state', 'file') == 'file':
+        if module == "file" and task["action"].get("state", "file") == "file":
             return False
 
         # replace module is the only one that has a valid default preserve
         # behavior, but we want to trigger rule if user used incorrect
         # documentation and put 'preserve', which is not supported.
-        if module == 'replace' and mode is None:
+        if module == "replace" and mode is None:
             return False
 
         return mode is None
@@ -126,33 +125,35 @@ class MissingFilePermissionsRule(AnsibleLintRule):
 if "pytest" in sys.modules:  # noqa: C901
     import pytest
 
-    SUCCESS_PERMISSIONS_PRESENT = '''
+    from ansiblelint.testing import RunFromText  # pylint: disable=ungrouped-imports
+
+    SUCCESS_PERMISSIONS_PRESENT = """
 - hosts: all
   tasks:
     - name: permissions not missing and numeric
       file:
         path: foo
         mode: 0600
-'''
+"""
 
-    SUCCESS_ABSENT_STATE = '''
+    SUCCESS_ABSENT_STATE = """
 - hosts: all
   tasks:
     - name: permissions missing while state is absent is fine
       file:
         path: foo
         state: absent
-'''
+"""
 
-    SUCCESS_DEFAULT_STATE = '''
+    SUCCESS_DEFAULT_STATE = """
 - hosts: all
   tasks:
     - name: permissions missing while state is file (default) is fine
       file:
         path: foo
-'''
+"""
 
-    SUCCESS_LINK_STATE = '''
+    SUCCESS_LINK_STATE = """
 - hosts: all
   tasks:
     - name: permissions missing while state is link is fine
@@ -160,9 +161,9 @@ if "pytest" in sys.modules:  # noqa: C901
         path: foo2
         src: foo
         state: link
-'''
+"""
 
-    SUCCESS_CREATE_FALSE = '''
+    SUCCESS_CREATE_FALSE = """
 - hosts: all
   tasks:
     - name: file edit when create is false
@@ -170,17 +171,17 @@ if "pytest" in sys.modules:  # noqa: C901
         path: foo
         create: false
         line: some content here
-'''
+"""
 
-    SUCCESS_REPLACE = '''
+    SUCCESS_REPLACE = """
 - hosts: all
   tasks:
     - name: replace should not require mode
       replace:
         path: foo
-'''
+"""
 
-    SUCCESS_RECURSE = '''
+    SUCCESS_RECURSE = """
 - hosts: all
   tasks:
     - name: file with recursive does not require mode
@@ -196,18 +197,18 @@ if "pytest" in sys.modules:  # noqa: C901
         path: foo
         create: false
         line: some content here
-'''
+"""
 
-    FAIL_PRESERVE_MODE = '''
+    FAIL_PRESERVE_MODE = """
 - hosts: all
   tasks:
     - name: file does not allow preserve value for mode
       file:
         path: foo
         mode: preserve
-'''
+"""
 
-    FAIL_MISSING_PERMISSIONS_TOUCH = '''
+    FAIL_MISSING_PERMISSIONS_TOUCH = """
 - hosts: all
   tasks:
     - name: permissions missing and might create file
@@ -218,9 +219,9 @@ if "pytest" in sys.modules:  # noqa: C901
       ansible.builtin.file:
         path: foo
         state: touch
-'''
+"""
 
-    FAIL_MISSING_PERMISSIONS_DIRECTORY = '''
+    FAIL_MISSING_PERMISSIONS_DIRECTORY = """
 - hosts: all
   tasks:
     - name: permissions missing and might create directory
@@ -232,9 +233,9 @@ if "pytest" in sys.modules:  # noqa: C901
         path: foo
         create: true
         line: some content here
-'''
+"""
 
-    FAIL_LINEINFILE_CREATE = '''
+    FAIL_LINEINFILE_CREATE = """
 - hosts: all
   tasks:
     - name: lineinfile when create is true
@@ -242,18 +243,18 @@ if "pytest" in sys.modules:  # noqa: C901
         path: foo
         create: true
         line: some content here
-'''
+"""
 
-    FAIL_REPLACE_PRESERVE = '''
+    FAIL_REPLACE_PRESERVE = """
 - hosts: all
   tasks:
     - name: replace does not allow preserve mode
       replace:
         path: foo
         mode: preserve
-'''
+"""
 
-    FAIL_PERMISSION_COMMENT = '''
+    FAIL_PERMISSION_COMMENT = """
 - hosts: all
   tasks:
     - name: permissions is only a comment
@@ -263,18 +264,18 @@ if "pytest" in sys.modules:  # noqa: C901
         group: root
         state: directory
         # mode: 0755
-'''
+"""
 
-    FAIL_INI_PERMISSION = '''
+    FAIL_INI_PERMISSION = """
 - hosts: all
     tasks:
      - name: permissions needed if create is used
        ini_file:
          path: foo
          create: true
-'''
+"""
 
-    FAIL_INI_PRESERVE = '''
+    FAIL_INI_PRESERVE = """
 - hosts: all
   tasks:
     - name: ini_file does not accept preserve mode
@@ -282,10 +283,10 @@ if "pytest" in sys.modules:  # noqa: C901
         path: foo
         create: true
         mode: preserve
-'''
+"""
 
     @pytest.mark.parametrize(
-        'rule_runner', (MissingFilePermissionsRule,), indirect=['rule_runner']
+        "rule_runner", (MissingFilePermissionsRule,), indirect=["rule_runner"]
     )
     def test_success_permissions_present(rule_runner: RunFromText) -> None:
         """Permissions present and numeric."""
@@ -293,7 +294,7 @@ if "pytest" in sys.modules:  # noqa: C901
         assert len(results) == 0
 
     @pytest.mark.parametrize(
-        'rule_runner', (MissingFilePermissionsRule,), indirect=['rule_runner']
+        "rule_runner", (MissingFilePermissionsRule,), indirect=["rule_runner"]
     )
     def test_success_absent_state(rule_runner: RunFromText) -> None:
         """No permissions required if file is absent."""
@@ -301,7 +302,7 @@ if "pytest" in sys.modules:  # noqa: C901
         assert len(results) == 0
 
     @pytest.mark.parametrize(
-        'rule_runner', (MissingFilePermissionsRule,), indirect=['rule_runner']
+        "rule_runner", (MissingFilePermissionsRule,), indirect=["rule_runner"]
     )
     def test_success_default_state(rule_runner: RunFromText) -> None:
         """No permissions required if default state."""
@@ -309,7 +310,7 @@ if "pytest" in sys.modules:  # noqa: C901
         assert len(results) == 0
 
     @pytest.mark.parametrize(
-        'rule_runner', (MissingFilePermissionsRule,), indirect=['rule_runner']
+        "rule_runner", (MissingFilePermissionsRule,), indirect=["rule_runner"]
     )
     def test_success_link_state(rule_runner: RunFromText) -> None:
         """No permissions required if it is a link."""
@@ -317,7 +318,7 @@ if "pytest" in sys.modules:  # noqa: C901
         assert len(results) == 0
 
     @pytest.mark.parametrize(
-        'rule_runner', (MissingFilePermissionsRule,), indirect=['rule_runner']
+        "rule_runner", (MissingFilePermissionsRule,), indirect=["rule_runner"]
     )
     def test_success_create_false(rule_runner: RunFromText) -> None:
         """No permissions required if file is not created."""
@@ -325,7 +326,7 @@ if "pytest" in sys.modules:  # noqa: C901
         assert len(results) == 0
 
     @pytest.mark.parametrize(
-        'rule_runner', (MissingFilePermissionsRule,), indirect=['rule_runner']
+        "rule_runner", (MissingFilePermissionsRule,), indirect=["rule_runner"]
     )
     def test_success_replace(rule_runner: RunFromText) -> None:
         """Replacing a file do not require mode."""
@@ -333,7 +334,7 @@ if "pytest" in sys.modules:  # noqa: C901
         assert len(results) == 0
 
     @pytest.mark.parametrize(
-        'rule_runner', (MissingFilePermissionsRule,), indirect=['rule_runner']
+        "rule_runner", (MissingFilePermissionsRule,), indirect=["rule_runner"]
     )
     def test_success_recurse(rule_runner: RunFromText) -> None:
         """Do not require mode when recursing."""
@@ -341,7 +342,7 @@ if "pytest" in sys.modules:  # noqa: C901
         assert len(results) == 0
 
     @pytest.mark.parametrize(
-        'rule_runner', (MissingFilePermissionsRule,), indirect=['rule_runner']
+        "rule_runner", (MissingFilePermissionsRule,), indirect=["rule_runner"]
     )
     def test_fail_preserve_mode(rule_runner: RunFromText) -> None:
         """File does not allow preserve value for mode."""
@@ -349,7 +350,7 @@ if "pytest" in sys.modules:  # noqa: C901
         assert len(results) == 1
 
     @pytest.mark.parametrize(
-        'rule_runner', (MissingFilePermissionsRule,), indirect=['rule_runner']
+        "rule_runner", (MissingFilePermissionsRule,), indirect=["rule_runner"]
     )
     def test_fail_missing_permissions_touch(rule_runner: RunFromText) -> None:
         """Missing permissions when possibly creating file."""
@@ -357,7 +358,7 @@ if "pytest" in sys.modules:  # noqa: C901
         assert len(results) == 2
 
     @pytest.mark.parametrize(
-        'rule_runner', (MissingFilePermissionsRule,), indirect=['rule_runner']
+        "rule_runner", (MissingFilePermissionsRule,), indirect=["rule_runner"]
     )
     def test_fail_missing_permissions_directory(rule_runner: RunFromText) -> None:
         """Missing permissions when possibly creating a directory."""
@@ -365,7 +366,7 @@ if "pytest" in sys.modules:  # noqa: C901
         assert len(results) == 2
 
     @pytest.mark.parametrize(
-        'rule_runner', (MissingFilePermissionsRule,), indirect=['rule_runner']
+        "rule_runner", (MissingFilePermissionsRule,), indirect=["rule_runner"]
     )
     def test_fail_lineinfile_create(rule_runner: RunFromText) -> None:
         """Lineinfile might create a file."""
@@ -373,7 +374,7 @@ if "pytest" in sys.modules:  # noqa: C901
         assert len(results) == 1
 
     @pytest.mark.parametrize(
-        'rule_runner', (MissingFilePermissionsRule,), indirect=['rule_runner']
+        "rule_runner", (MissingFilePermissionsRule,), indirect=["rule_runner"]
     )
     def test_fail_replace_preserve(rule_runner: RunFromText) -> None:
         """Replace does not allow preserve mode."""
@@ -381,7 +382,7 @@ if "pytest" in sys.modules:  # noqa: C901
         assert len(results) == 1
 
     @pytest.mark.parametrize(
-        'rule_runner', (MissingFilePermissionsRule,), indirect=['rule_runner']
+        "rule_runner", (MissingFilePermissionsRule,), indirect=["rule_runner"]
     )
     def test_fail_permission_comment(rule_runner: RunFromText) -> None:
         """Permissions is only a comment."""
@@ -389,7 +390,7 @@ if "pytest" in sys.modules:  # noqa: C901
         assert len(results) == 1
 
     @pytest.mark.parametrize(
-        'rule_runner', (MissingFilePermissionsRule,), indirect=['rule_runner']
+        "rule_runner", (MissingFilePermissionsRule,), indirect=["rule_runner"]
     )
     def test_fail_ini_permission(rule_runner: RunFromText) -> None:
         """Permissions needed if create is used."""
@@ -397,7 +398,7 @@ if "pytest" in sys.modules:  # noqa: C901
         assert len(results) == 1
 
     @pytest.mark.parametrize(
-        'rule_runner', (MissingFilePermissionsRule,), indirect=['rule_runner']
+        "rule_runner", (MissingFilePermissionsRule,), indirect=["rule_runner"]
     )
     def test_fail_ini_preserve(rule_runner: RunFromText) -> None:
         """The ini_file module does not accept preserve mode."""
