@@ -17,9 +17,17 @@ def strip_ansi_escape(data: Union[str, bytes]) -> str:
 
 def toidentifier(text: str) -> str:
     """Convert unsafe chars to ones allowed in variables."""
-    result = re.sub(r"[\s-]+", '_', text)
+    result = re.sub(r"[\s-]+", "_", text)
     if not result.isidentifier:
         raise RuntimeError(
             "Unable to convert role name '%s' to valid variable name." % text
         )
     return result
+
+
+# https://www.python.org/dev/peps/pep-0616/
+def removeprefix(self: str, prefix: str) -> str:
+    """Remove prefix from string."""
+    if self.startswith(prefix):
+        return self[len(prefix) :]
+    return self[:]
